# 断面算定がOKとなる梁・柱の鉄骨断面を求める

## 本プログラムの説明
『SS7』で計算を繰り返し行い、断面算定（曲げ・せん断）がOKとなる梁・柱の鉄骨断面を求めるプログラムです。<br>

**鉄骨断面の求め方**<br>
断面算定の曲げ検定比・せん断検定比が1.00を超える場合、当該部材の鉄骨断面を[6.鋼材リスト]に登録されている次の鋼材に変更し、再度計算を行い、曲げとせん断の検定比を満足する鉄骨断面になるまで、繰り返し計算を行います。<br>
梁の鉄骨断面は、左端の鉄骨断面をベースとして、曲げまたはせん断の検定比が1.00を超える場合、全断面（左端・中央・右端）を左端の鉄骨断面の[6.鋼材リスト]に登録されている次の鋼材に変更します。<br>
組み合わせ応力度・たわみ・全強接合（継手）・保有耐力接合（継手・仕口）・保有耐力横補剛・幅厚比は、断面算定を満足する対象外とします。

## 本プログラムの実行方法
1. **データ準備**: 対象とする物件の入力csvファイルを`input`フォルダに保存します。
2. **パラメータ設定**: `main.py`ファイルを編集して必要なパラメータを設定します。
    | 変数名 | 説明 | デフォルト |
    | :---- |----- | :------: |
    | input_csv_name | 入力csvファイル名 | "input.csv" |
    | max_count | 最大計算回数 |     100     |

3. **プログラム実行**：コマンドラインからプログラムを実行します。<br>
例) C:に「example」というフォルダ名で配置する場合
    ```cmd
    cd C:\example\src
    python main.py
    ```

4. **結果の確認**: 結果は`output`フォルダ内の`入力csvファイル名`フォルダに保存されます。<br>
`入力csvファイル名`フォルダの中身は以下です。<br>
　・Ss7Data.ikn（物件データ）<br>
　・input.csv（入力csv）<br>
　・result.csv（結果csv）<br>

## 注意事項
* 本プログラムは『SS7』Ver1.1.1.19専用です。<br>
Ver1.1.1.19以外で生成した入力csvでは正しく動作しません。
* プログラムの使用にあたっては、適切なデータファイルの準備やパラメータの設定が必要です。
* `output`フォルダ内に同じ名前の`入力csvファイル名`フォルダがある場合、上書きされます。
* 同一符号名（添字＋符号）が存在すると、部材断面の更新が正しく行えません。<br>
  符号の前に付ける添字を省略する場合は、添字に「`-`」を指定してください。
* 部材断面を変更しながら計算を繰り返しますので、メーカー製柱脚が配置されている柱の鉄骨断面が変更されると、計算が流れなくなります。<br>
  メーカー製柱脚が配置されている場合は、「`なし`」に変更したデータを使用してください。
* [6.鋼材リスト]に、同一断面の鋼材が登録されていると、計算が繰り返されることになり、収束しません。
* 基礎免震が指定されているデータは、対象外とします。
* 断面性能直接入力部材は、対象外とします。
* 断面算定省略の指定がある部材は、対象外となります。


## 『Op.Python実行』の設定手順
Ss7Pythonライブラリを使用するための設定手順です。
1. 『SS7』を起動し，[ツール－環境設定－Op.Python実行]画面を表示します。
2. “利用可能なPython言語のバージョン”を選択し，[デスクトップへコピー]ボタンをクリックします。
3. デスクトップにある「Python」フォルダごと，「src」フォルダにコピーします。


## 必要な外部ライブラリ
外部ライブラリは不要です。

## 著作者
Copyright(C) 2024 UNION SYSTEM Inc.


## ライセンス
本プログラムは MIT License に基づいています。「LICENSE」を確認してください。
